@@ -1,14 +1,10 @@
+//! Make some noise via cpal.
 #![allow(clippy::precedence)]
 
-extern crate anyhow;
-extern crate cpal;
-extern crate fundsp;
-
 use cpal::traits::{DeviceTrait, HostTrait, StreamTrait};
 
 use fundsp::hacker::*;
 
-#[cfg_attr(target_os = "android", ndk_glue::main(backtrace = "full"))]
 fn main() {
     let host = cpal::default_host();
 
@@ -39,19 +35,7 @@ where
 
     //let f = 110.0;
     //let m = 5.0;
-    //let c = sine_hz(f) * f * m + f >> sine();
-
-    // Risset glissando.
-    /*let c = stack::<U20, _, _>(|i| {
-        lfo(move |t| {
-            let f = lerp(-0.5, 0.5, rnd(i))
-                + xerp(20.0, 20480.0, (t * 0.1 + i as f64 * 0.5) % 10.0 / 10.0);
-            let a = smooth3(sin_hz(0.05, (t * 0.1 + i as f64 * 0.5) % 10.0));
-            (a, f)
-        }) >> pass() * sine() * 10.0
-    }) >> multijoin::<U1, U20>()
-        >> pinkpass();
-    */
+    //let c = oversample(sine_hz(f) * f * m + f >> sine()) >> pan(0.0);
 
     // Pulse wave.
     let c = lfo(|t| {
@@ -70,19 +54,22 @@ where
     //let c = lfo(|t| xerp11(50.0, 5000.0, ease_noise(smooth9, 0, t))) >> triangle();
 
     //let c = c
-    //    >> (pass() | envelope(|t| xerp(500.0, 20000.0, sin_hz(0.0666, t))) | dc(10.0))
-    //    >> bandpass();
-
-    //let c = c >> feedback(butterpass_hz(1000.0) >> delay(1.0) * 0.5);
+    //    >> (pass() | envelope(|t| xerp(500.0, 20000.0, sin_hz(0.0666, t))))
+    //    >> bandpass_q(1.0);
 
     // Waveshapers.
     //let c = c >> shape_fn(|x| tanh(x * 5.0));
 
-    //let c = (c | lfo(|t| (xerp11(100.0, 5000.0, sin_hz(0.1, t)), 0.8))) >> moog();
+    //let c = c & c >> feedback(butterpass_hz(1000.0) >> delay(1.0) * 0.5);
+
+    let c = (c | lfo(|t| (xerp11(110.0, 11000.0, sin_hz(0.15, t)), 0.6))) >> moog();
+
+    let c = c >> split::<U2>();
+
+    //let c = fundsp::sound::risset_glissando(false);
 
     let mut c = c
-        >> declick() >> dcblock()
-        >> split::<U2>()
+        >> (declick() | declick()) >> (dcblock() | dcblock())
         //>> reverb_stereo(0.2, 5.0)
         >> limiter_stereo((1.0, 5.0));
     //let mut c = c * 0.1;
