@@ -11,6 +11,7 @@ pub use super::filter::*;
 pub use super::fir::*;
 pub use super::math::*;
 pub use super::moog::*;
+pub use super::net::*;
 pub use super::noise::*;
 pub use super::oscillator::*;
 pub use super::oversample::*;
@@ -1467,3 +1468,17 @@ pub fn highshelf_q(
 pub fn pulse() -> An<super::prelude::PulseWave<f64>> {
     super::prelude::pulse()
 }
+
+/// Play back a channel of a Wave64.
+/// Optional loop point is the index to jump to at the end of the wave.
+/// - Output 0: wave
+pub fn wave64(wave: &Wave64, channel: usize, loop_point: Option<usize>) -> An<Wave64Player<f64>> {
+    An(Wave64Player::new(wave, channel, loop_point))
+}
+
+/// Play back a channel of a Wave32.
+/// Optional loop point is the index to jump to at the end of the wave.
+/// - Output 0: wave
+pub fn wave32(wave: &Wave32, channel: usize, loop_point: Option<usize>) -> An<Wave32Player<f64>> {
+    An(Wave32Player::new(wave, channel, loop_point))
+}
